Package: dupRadar
Type: Package
Title: Assessment of duplication rates in RNA-Seq datasets
Version: 1.43.0
Date: 2015-09-26
Author: Sergi Sayols <sergisayolspuig@gmail.com>, Holger Klein
        <holger.klein@gmail.com>
Maintainer: Sergi Sayols <sergisayolspuig@gmail.com>, Holger Klein
 <holger.klein@gmail.com>
Description: Duplication rate quality control for RNA-Seq datasets.
URL: https://www.bioconductor.org/packages/dupRadar,
        https://ssayols.github.io/dupRadar/index.html
VignetteBuilder: knitr
Suggests: BiocStyle, knitr, rmarkdown, AnnotationHub
Depends: R (>= 3.2.0)
Imports: Rsubread (>= 1.14.1), KernSmooth
LazyData: true
License: GPL-3
biocViews: Technology, Sequencing, RNASeq, QualityControl,
        ImmunoOncology
NeedsCompilation: no
Encoding: UTF-8
RoxygenNote: 7.3.2
Config/Bioconductor/UnsupportedPlatforms: windows
git_url: https://git.bioconductor.org/packages/dupRadar
git_branch: devel
git_last_commit: 26451be
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
Packaged: 2026-04-28 22:26:14 UTC; biocbuild
